==> western-world-3.0.123.tgz: package/src/svg/index.js <==
export const others = {
  'background-top-elements.svg': require('./others/background-top-elements.svg'),
  'background.svg': require('./others/background.svg'),
  'circle-is-done.svg': require('./others/circle-is-done.svg'),
  'colony-arrows.svg': require('./others/colony-arrows.svg'),
  'desert.svg': require('./others/desert.svg'),
  'flag.svg': require('./others/flag.svg'),
  'forest.svg': require('./others/forest.svg'),
  'progress.svg': require('./others/progress.svg'),
  'star.svg': require('./others/star.svg'),
  'start.svg': require('./others/start.svg'),
};

export const cells = {
  'abcde.svg': require('./cells/abcde.svg'),
  'accident.svg': {
    svgPath: require('./cells/accident.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/accident.scss').default,
  },
  'ads.svg': require('./cells/ads.svg'),
  'ambulance.svg': require('./cells/ambulance.svg'),
  'army.svg': require('./cells/army.svg'),
  'attempt_to_kill_player.svg': require('./cells/attempt_to_kill_player.svg'),
  'auction_started.svg': require('./cells/auction_started.svg'),
  'bamper.svg': require('./cells/bamper.svg'),
  'banana_plantation.svg': require('./cells/banana_plantation.svg'),
  'bank.svg': {
    svgPath: require('./cells/bank.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_27.svg': {
    svgPath: require('./cells/bank_27.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_8.svg': {
    svgPath: require('./cells/bank_8.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_crash.svg': require('./cells/bank_crash.svg'),
  'bank_jungle.svg': require('./cells/bank_jungle.svg'),
  'bank_robbery.svg': require('./cells/bank_robbery.svg'),
  'bermuda_triangle.svg': require('./cells/bermuda_triangle.svg'),
  'bet_on_star_won_40.svg': require('./cells/bet_on_star_won_40.svg'),
  'bet_on_star_won_41.svg': require('./cells/bet_on_star_won_41.svg'),
  'bought_10_cars.svg': require('./cells/bought_10_cars.svg'),
  'bought_drugs_10_tons.svg': require('./cells/bought_drugs_10_tons.svg'),
  'bread_plantation.svg': require('./cells/bread_plantation.svg'),
  'bribery_of_police.svg': {
    svgPath: require('./cells/bribery_of_police.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bribery_of_police.scss').default,
  },
  'bribery_of_the_labor_aristocracy.svg': require('./cells/bribery_of_the_labor_aristocracy.svg'),
  'broadcast.svg': require('./cells/broadcast.svg'),
  'broiler_digest.svg': require('./cells/broiler_digest.svg'),
  'broken_safe.svg': require('./cells/broken_safe.svg'),
  'buy_barrel_oil.svg': require('./cells/buy_barrel_oil.svg'),
  'buy_gold.svg': require('./cells/buy_gold.svg'),
  'cafe_bogema.svg': require('./cells/cafe_bogema.svg'),
  'came_back.svg': require('./cells/came_back.svg'),
  'casino.svg': require('./cells/casino.svg'),
  'coffee.svg': require('./cells/coffee.svg'),
  'coffee_break.svg': require('./cells/coffee_break.svg'),
  'commodityexchange_15.svg': require('./cells/commodityexchange_15.svg'),
  'commodityexchange_26.svg': require('./cells/commodityexchange_26.svg'),
  'commodityexchange_33.svg': require('./cells/commodityexchange_33.svg'),
  'contribution_to_the_brain.svg': {
    svgPath: require('./cells/contribution_to_the_brain.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/contribution_to_the_brain.scss').default,
  },
  'crack_house.svg': require('./cells/crack_house.svg'),
  'crisis_of_confidence.svg': require('./cells/crisis_of_confidence.svg'),
  'crocodile.svg': require('./cells/crocodile.svg'),
  'crop_failure.svg': require('./cells/crop_failure.svg'),
  'deceive.svg': require('./cells/deceive.svg'),
  'decided_to_stop_the_game.svg': {
    svgPath: require('./cells/decided_to_stop_the_game.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/decided_to_stop_the_game.scss').default,
  },
  'desert_island.svg': require('./cells/desert_island.svg'),
  'doomsday.svg': require('./cells/doomsday.svg'),
  'drugs_104.svg': require('./cells/drugs_104.svg'),
  'drugs_109.svg': require('./cells/drugs_109.svg'),
  'drugs_plantation.svg': require('./cells/drugs_plantation.svg'),
  'drunk_skip_two_times.svg': require('./cells/drunk_skip_two_times.svg'),
  'dumping.svg': require('./cells/dumping.svg'),
  'ema.svg': require('./cells/ema.svg'),
  'empty_cell.svg': require('./cells/empty_cell.svg'),
  'extortion.svg': require('./cells/extortion.svg'),
  'fake_coins.svg': require('./cells/fake_coins.svg'),
  'famine_and_epidemic.svg': require('./cells/famine_and_epidemic.svg'),
  'farm.svg': require('./cells/farm.svg'),
  'gave_godfather.svg': require('./cells/gave_godfather.svg'),
  'godfather.svg': require('./cells/godfather.svg'),
  'gold_bucket.svg': require('./cells/gold_bucket.svg'),
  'gold_mine.svg': require('./cells/gold_mine.svg'),
  'golden_tooth.svg': require('./cells/golden_tooth.svg'),
  'got_into_an_accident.svg': require('./cells/got_into_an_accident.svg'),
  'hijacking.svg': require('./cells/hijacking.svg'),
  'hmm.svg': require('./cells/hmm.svg'),
  'insurance_10k.svg': require('./cells/insurance_10k.svg'),
  'investment.svg': require('./cells/investment.svg'),
  'investment_objective.svg': require('./cells/investment_objective.svg'),
  'item_amount_items48_buy.svg': require('./cells/item_amount_items48_buy.svg'),
  'item_amount_items48_sell.svg': require('./cells/item_amount_items48_sell.svg'),
  'justice.svg': require('./cells/justice.svg'),
  'labor_cost_index_down_19.svg': require('./cells/labor_cost_index_down_19.svg'),
  'labor_cost_index_up_32.svg': require('./cells/labor_cost_index_up_32.svg'),
  'loan.svg': require('./cells/loan.svg'),
  'mmm.svg': require('./cells/mmm.svg'),
  'multiple_money.svg': require('./cells/multiple_money.svg'),
  'mutiny_on_the_ship.svg': require('./cells/mutiny_on_the_ship.svg'),
  'night_robbery.svg': require('./cells/night_robbery.svg'),
  'no_taxes.svg': require('./cells/no_taxes.svg'),
  'official_triumph.svg': require('./cells/official_triumph.svg'),
  'pay_tax_33_percent.svg': require('./cells/pay_tax_33_percent.svg'),
  'pearls_was_bought.svg': require('./cells/pearls_was_bought.svg'),
  'perls.svg': require('./cells/perls.svg'),
  'pirates.svg': require('./cells/pirates.svg'),
  'plantations_brought_profit.svg': require('./cells/plantations_brought_profit.svg'),
  'player_lock.svg': require('./cells/player_lock.svg'),
  'player_lock_103.svg': require('./cells/player_lock_103.svg'),
  'player_lock_105.svg': require('./cells/player_lock_105.svg'),
  'player_lock_107.svg': require('./cells/player_lock_107.svg'),
  'player_lock_92.svg': require('./cells/player_lock_92.svg'),
  'player_lock_drugs_plantation.svg': require('./cells/player_lock_drugs_plantation.svg'),
  'population_explosion.svg': require('./cells/population_explosion.svg'),
  'port.svg': require('./cells/port.svg'),
  'president_tax.svg': require('./cells/president_tax.svg'),
  'protess_mission.svg': require('./cells/protess_mission.svg'),
  'put_money_on_a_star.svg': require('./cells/put_money_on_a_star.svg'),
  'question_mark.svg': require('./cells/question_mark.svg'),
  'racket.svg': require('./cells/racket.svg'),
  'rebellion_in_colony.svg': require('./cells/rebellion_in_colony.svg'),
  'rent_for_pearls.svg': require('./cells/rent_for_pearls.svg'),
  'robbery_gold.svg': require('./cells/robbery_gold.svg'),
  'saloon.svg': require('./cells/saloon.svg'),
  'shipwreck.svg': require('./cells/shipwreck.svg'),
  'shipyards.svg': require('./cells/shipyards.svg'),
  'shooting.svg': require('./cells/shooting.svg'),
  'slave_market.svg': require('./cells/slave_market.svg'),
  'sleep.svg': require('./cells/sleep.svg'),
  'steal_statue.svg': require('./cells/steal_statue.svg'),
  'stock_exchange.svg': {
    svgPath: require('./cells/stock_exchange.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'stock_exchange_speculation_18.svg': require('./cells/stock_exchange_speculation_18.svg'),
  'stock_exchange_speculation_24.svg': require('./cells/stock_exchange_speculation_24.svg'),
  'stock_exchange_speculation_81.svg': require('./cells/stock_exchange_speculation_81.svg'),
  'street_29.svg': require('./cells/street_29.svg'),
  'street_49.svg': require('./cells/street_49.svg'),
  'street_63.svg': require('./cells/street_63.svg'),
  'street_78.svg': require('./cells/street_78.svg'),
  'strike.svg': require('./cells/strike.svg'),
  'swimming_in_the_coca_cola.svg': require('./cells/swimming_in_the_coca_cola.svg'),
  'take_away_money_in.svg': require('./cells/take_away_money_in.svg'),
  'take_from_budget.svg': require('./cells/take_from_budget.svg'),
  'tax_on_plantations.svg': require('./cells/tax_on_plantations.svg'),
  'terrorist.svg': require('./cells/terrorist.svg'),
  'three_kg_gold_treasure_found.svg': require('./cells/three_kg_gold_treasure_found.svg'),
  'travel_agency.svg': require('./cells/travel_agency.svg'),
  'triple_step.svg': require('./cells/triple_step.svg'),
  'war_factory.svg': require('./cells/war_factory.svg'),
  'will_not_bring_profit.svg': require('./cells/will_not_bring_profit.svg'),
};

==> western-world-3.0.124.tgz: package/src/svg/index.js <==
export const others = {
  'background-top-elements.svg': require('./others/background-top-elements.svg'),
  'background.svg': require('./others/background.svg'),
  'circle-is-done.svg': require('./others/circle-is-done.svg'),
  'colony-arrows.svg': require('./others/colony-arrows.svg'),
  'desert.svg': require('./others/desert.svg'),
  'flag.svg': require('./others/flag.svg'),
  'forest.svg': require('./others/forest.svg'),
  'progress.svg': require('./others/progress.svg'),
  'star.svg': require('./others/star.svg'),
  'start.svg': require('./others/start.svg'),
};

export const cells = {
  'abcde.svg': require('./cells/abcde.svg'),
  'accident.svg': {
    svgPath: require('./cells/accident.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/accident.scss').default,
  },
  'ads.svg': require('./cells/ads.svg'),
  'ambulance.svg': require('./cells/ambulance.svg'),
  'army.svg': require('./cells/army.svg'),
  'attempt_to_kill_player.svg': require('./cells/attempt_to_kill_player.svg'),
  'auction_started.svg': require('./cells/auction_started.svg'),
  'bamper.svg': require('./cells/bamper.svg'),
  'banana_plantation.svg': require('./cells/banana_plantation.svg'),
  'bank.svg': {
    svgPath: require('./cells/bank.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_27.svg': {
    svgPath: require('./cells/bank_27.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_8.svg': {
    svgPath: require('./cells/bank_8.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'bank_crash.svg': require('./cells/bank_crash.svg'),
  'bank_jungle.svg': require('./cells/bank_jungle.svg'),
  'bank_robbery.svg': require('./cells/bank_robbery.svg'),
  'bermuda_triangle.svg': require('./cells/bermuda_triangle.svg'),
  'bet_on_star_won_40.svg': require('./cells/bet_on_star_won_40.svg'),
  'bet_on_star_won_41.svg': require('./cells/bet_on_star_won_41.svg'),
  'bought_10_cars.svg': require('./cells/bought_10_cars.svg'),
  'bought_drugs_10_tons.svg': require('./cells/bought_drugs_10_tons.svg'),
  'bread_plantation.svg': require('./cells/bread_plantation.svg'),
  'bribery_of_police.svg': {
    svgPath: require('./cells/bribery_of_police.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bribery_of_police.scss').default,
  },
  'bribery_of_the_labor_aristocracy.svg': require('./cells/bribery_of_the_labor_aristocracy.svg'),
  'broadcast.svg': require('./cells/broadcast.svg'),
  'broiler_digest.svg': require('./cells/broiler_digest.svg'),
  'broken_safe.svg': require('./cells/broken_safe.svg'),
  'buy_barrel_oil.svg': require('./cells/buy_barrel_oil.svg'),
  'buy_gold.svg': {
    svgPath: require('./cells/buy_gold.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/gold_bucket.scss').default,
  },
  'cafe_bogema.svg': require('./cells/cafe_bogema.svg'),
  'came_back.svg': require('./cells/came_back.svg'),
  'casino.svg': require('./cells/casino.svg'),
  'coffee.svg': require('./cells/coffee.svg'),
  'coffee_break.svg': require('./cells/coffee_break.svg'),
  'commodityexchange_15.svg': require('./cells/commodityexchange_15.svg'),
  'commodityexchange_26.svg': require('./cells/commodityexchange_26.svg'),
  'commodityexchange_33.svg': require('./cells/commodityexchange_33.svg'),
  'contribution_to_the_brain.svg': {
    svgPath: require('./cells/contribution_to_the_brain.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/contribution_to_the_brain.scss').default,
  },
  'crack_house.svg': require('./cells/crack_house.svg'),
  'crisis_of_confidence.svg': require('./cells/crisis_of_confidence.svg'),
  'crocodile.svg': require('./cells/crocodile.svg'),
  'crop_failure.svg': require('./cells/crop_failure.svg'),
  'deceive.svg': require('./cells/deceive.svg'),
  'decided_to_stop_the_game.svg': {
    svgPath: require('./cells/decided_to_stop_the_game.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/decided_to_stop_the_game.scss').default,
  },
  'desert_island.svg': {
    svgPath: require('./cells/desert_island.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/desert_island.scss').default,
  },
  'doomsday.svg': require('./cells/doomsday.svg'),
  'drugs_104.svg': require('./cells/drugs_104.svg'),
  'drugs_109.svg': require('./cells/drugs_109.svg'),
  'drugs_plantation.svg': require('./cells/drugs_plantation.svg'),
  'drunk_skip_two_times.svg': require('./cells/drunk_skip_two_times.svg'),
  'dumping.svg': require('./cells/dumping.svg'),
  'ema.svg': require('./cells/ema.svg'),
  'empty_cell.svg': require('./cells/empty_cell.svg'),
  'extortion.svg': require('./cells/extortion.svg'),
  'fake_coins.svg': require('./cells/fake_coins.svg'),
  'famine_and_epidemic.svg': require('./cells/famine_and_epidemic.svg'),
  'farm.svg': require('./cells/farm.svg'),
  'gave_godfather.svg': require('./cells/gave_godfather.svg'),
  'godfather.svg': require('./cells/godfather.svg'),
  'gold_bucket.svg': {
    svgPath: require('./cells/gold_bucket.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/gold_bucket.scss').default,
  },
  'gold_mine.svg': require('./cells/gold_mine.svg'),
  'golden_tooth.svg': {
    svgPath: require('./cells/golden_tooth.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/gold_bucket.scss').default,
  },
  'got_into_an_accident.svg': require('./cells/got_into_an_accident.svg'),
  'hijacking.svg': require('./cells/hijacking.svg'),
  'hmm.svg': require('./cells/hmm.svg'),
  'insurance_10k.svg': require('./cells/insurance_10k.svg'),
  'investment.svg': require('./cells/investment.svg'),
  'investment_objective.svg': require('./cells/investment_objective.svg'),
  'item_amount_items48_buy.svg': require('./cells/item_amount_items48_buy.svg'),
  'item_amount_items48_sell.svg': require('./cells/item_amount_items48_sell.svg'),
  'justice.svg': require('./cells/justice.svg'),
  'labor_cost_index_down_19.svg': require('./cells/labor_cost_index_down_19.svg'),
  'labor_cost_index_up_32.svg': require('./cells/labor_cost_index_up_32.svg'),
  'loan.svg': require('./cells/loan.svg'),
  'mmm.svg': require('./cells/mmm.svg'),
  'multiple_money.svg': require('./cells/multiple_money.svg'),
  'mutiny_on_the_ship.svg': require('./cells/mutiny_on_the_ship.svg'),
  'night_robbery.svg': require('./cells/night_robbery.svg'),
  'no_taxes.svg': require('./cells/no_taxes.svg'),
  'official_triumph.svg': require('./cells/official_triumph.svg'),
  'pay_tax_33_percent.svg': require('./cells/pay_tax_33_percent.svg'),
  'pearls_was_bought.svg': require('./cells/pearls_was_bought.svg'),
  'perls.svg': require('./cells/perls.svg'),
  'pirates.svg': require('./cells/pirates.svg'),
  'plantations_brought_profit.svg': require('./cells/plantations_brought_profit.svg'),
  'player_lock.svg': require('./cells/player_lock.svg'),
  'player_lock_103.svg': require('./cells/player_lock_103.svg'),
  'player_lock_105.svg': require('./cells/player_lock_105.svg'),
  'player_lock_107.svg': require('./cells/player_lock_107.svg'),
  'player_lock_92.svg': require('./cells/player_lock_92.svg'),
  'player_lock_drugs_plantation.svg': require('./cells/player_lock_drugs_plantation.svg'),
  'population_explosion.svg': require('./cells/population_explosion.svg'),
  'port.svg': require('./cells/port.svg'),
  'president_tax.svg': require('./cells/president_tax.svg'),
  'protess_mission.svg': require('./cells/protess_mission.svg'),
  'put_money_on_a_star.svg': require('./cells/put_money_on_a_star.svg'),
  'question_mark.svg': require('./cells/question_mark.svg'),
  'racket.svg': require('./cells/racket.svg'),
  'rebellion_in_colony.svg': require('./cells/rebellion_in_colony.svg'),
  'rent_for_pearls.svg': require('./cells/rent_for_pearls.svg'),
  'robbery_gold.svg': require('./cells/robbery_gold.svg'),
  'saloon.svg': require('./cells/saloon.svg'),
  'shipwreck.svg': require('./cells/shipwreck.svg'),
  'shipyards.svg': require('./cells/shipyards.svg'),
  'shooting.svg': require('./cells/shooting.svg'),
  'slave_market.svg': require('./cells/slave_market.svg'),
  'sleep.svg': require('./cells/sleep.svg'),
  'steal_statue.svg': require('./cells/steal_statue.svg'),
  'stock_exchange.svg': {
    svgPath: require('./cells/stock_exchange.svg'),
    scssPath: require('!!css-loader!sass-loader!../scss/cells/bank_and_stock.scss').default,
  },
  'stock_exchange_speculation_18.svg': require('./cells/stock_exchange_speculation_18.svg'),
  'stock_exchange_speculation_24.svg': require('./cells/stock_exchange_speculation_24.svg'),
  'stock_exchange_speculation_81.svg': require('./cells/stock_exchange_speculation_81.svg'),
  'street_29.svg': require('./cells/street_29.svg'),
  'street_49.svg': require('./cells/street_49.svg'),
  'street_63.svg': require('./cells/street_63.svg'),
  'street_78.svg': require('./cells/street_78.svg'),
  'strike.svg': require('./cells/strike.svg'),
  'swimming_in_the_coca_cola.svg': require('./cells/swimming_in_the_coca_cola.svg'),
  'take_away_money_in.svg': require('./cells/take_away_money_in.svg'),
  'take_from_budget.svg': require('./cells/take_from_budget.svg'),
  'tax_on_plantations.svg': require('./cells/tax_on_plantations.svg'),
  'terrorist.svg': require('./cells/terrorist.svg'),
  'three_kg_gold_treasure_found.svg': require('./cells/three_kg_gold_treasure_found.svg'),
  'travel_agency.svg': require('./cells/travel_agency.svg'),
  'triple_step.svg': require('./cells/triple_step.svg'),
  'war_factory.svg': require('./cells/war_factory.svg'),
  'will_not_bring_profit.svg': require('./cells/will_not_bring_profit.svg'),
};
